[vlc-commits] commit: Qt: correct the size behaviour when zoom is called ( Jean-Baptiste Kempf )

git at videolan.org git at videolan.org
Tue Mar 30 18:36:31 CEST 2010


vlc | branch: master | Jean-Baptiste Kempf <jb at videolan.org> | Tue Mar 30 18:34:31 2010 +0200| [126c2decc17a9a2a56121c68fb6c6bdc54884d19] | committer: Jean-Baptiste Kempf 

Qt: correct the size behaviour when zoom is called

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=126c2decc17a9a2a56121c68fb6c6bdc54884d19
---

 modules/gui/qt4/main_interface.cpp |    7 +++++--
 1 files changed, 5 insertions(+), 2 deletions(-)

diff --git a/modules/gui/qt4/main_interface.cpp b/modules/gui/qt4/main_interface.cpp
index 953fd4b..1b9c38c 100644
--- a/modules/gui/qt4/main_interface.cpp
+++ b/modules/gui/qt4/main_interface.cpp
@@ -587,8 +587,9 @@ void MainInterface::getVideoSlot( WId *p_id, int *pi_x, int *pi_y,
     *p_id = ret;
     if( ret ) /* The videoWidget is available */
     {
-        /* ask videoWidget to show */
-        videoWidget->SetSizing( *pi_width, *pi_height );
+        /* Ask videoWidget to resize correctly, if we are in normal mode */
+        if( !isFullScreen() && !isMaximized() )
+            videoWidget->SetSizing( *pi_width, *pi_height );
 
         /* Consider the video active now */
         showVideo();
@@ -621,6 +622,8 @@ int MainInterface::controlVideo( int i_query, va_list args )
     {
         unsigned int i_width  = va_arg( args, unsigned int );
         unsigned int i_height = va_arg( args, unsigned int );
+        if( isFullScreen() || isMaximized() )
+            showNormal();
         emit askVideoToResize( i_width, i_height );
         return VLC_SUCCESS;
     }



More information about the vlc-commits mailing list